@@ -1,6 +1,6 @@
 /*
-   Copyright 2011-2012 ALT Linux
-   Copyright 2011-2012 Michael Pozhidaev
+   Copyright 2011-2013 ALT Linux
+   Copyright 2011-2013 Michael Pozhidaev
 
    This file is part of the Deepsolver.
 
@@ -19,50 +19,9 @@
 #define DEEPSOLVER_OPERATION_CORE_H
 
 #include"ConfigCenter.h"
-
-/**\brief The abstract interface for continuous process interruption
- *
- * Various continuous processes (such as downloading) ask external object
- * to be sure the user do not want to interrupt the task being
- * performed. This class declares the interface for objects to provide
- * such information. It is called multiple times during the work. Any
- * negative answer causes immediate process cancelling.
- *
- * \sa OperationCore
- */
-class AbstractOperationContinueRequest
-{
-public:
-  /**\brief The destructor*/
-  virtual ~AbstractOperationContinueRequest() {}
-
-public:
-  /**\brief Asks external structures to continue operation
-   *
-   * Implement this method to be able interrupt continuous operations.
-   *
-   * \return Non-zero means to continue operation
-   */
-  virtual bool onContinueOperationRequest() const = 0;
-}; //class AbstractOperationContinueRequest; 
-
-class AbstractIndexFetchListener
-{
-public:
-  virtual ~AbstractIndexFetchListener() {}
-
-public:
-  virtual void onInfoFilesFetch() = 0;
-  virtual void onIndexFetchBegin() = 0;
-  virtual void onIndexFilesReading() = 0;
-  virtual void onIndexFetchComplete() = 0;
-  virtual void onIndexFetchStatus(unsigned char currentPartPercents,
-				  unsigned char totalPercents,
-				  size_t partNumber,
-				  size_t partCount,
-				  size_t currentPartSize,
-				  const std::string& currentPartName) = 0;
-}; //class AbstractIndexFetchListener;
+#include"TransactionIterator.h"
+#include"AbstractOperationContinueRequest.h"
+#include"AbstractFetchListener.h"
 
 class AbstractTransactionListener
 {
@@ -79,12 +38,33 @@ public:
   virtual void onInstallRemovePkgListProcessing() = 0;
 }; //class abstractTransactionListener;
 
+/**\brief The main class for package managing
+ *
+ * The OperationCore class is the central class of Deepsolver project. It
+ * allows every client to perform various manipulations with packages
+ * including installation, removing and upgrading. In addition this class
+ * takes care of information gathered about attached repositories. 
+ *
+ * Be careful, each method of the OperationCore class throws a number of
+ * exceptions. Their exact set depends on method purpose. The main
+ * structure used for configuring is a ConfigCenter class instance
+ * provided by a reference to OperationCore constructor.
+ *
+ * According to accepted project design there are two additional classes
+ * purposed for direct client using as well as OperationCore itself:
+ * IndexCore and InfoCore. The former takes care about index construction
+ * and the second provides various information about known
+ * packages. These three classes are the main classes a end-user could be
+ * interested in.
+ *
+ * \sa IndexCore InfoCore OperationException
+ */
 class OperationCore
 {
 public:
-  /**\brief constructor
+  /**\brief The constructor
    *
-   * \param [in] conf The configuration data
+   * \param [in] conf A reference to configuration data object
    */
   OperationCore(const ConfigCenter& conf): 
     m_conf(conf)  {}
@@ -99,11 +79,12 @@ public:
      * \throws CurlException
      * \throws SystemException
      */
-  void fetchIndices(AbstractIndexFetchListener& listener,
+  void fetchIndices(AbstractFetchListener& listener,
 		    const AbstractOperationContinueRequest& continueRequest) const;
 
-  void transaction(AbstractTransactionListener& listener, const UserTask& task) const;
+  std::auto_ptr<TransactionIterator> transaction(AbstractTransactionListener& listener, const UserTask& task) const;
   std::string generateSat(AbstractTransactionListener& listener, const UserTask& task) const;
+  void printPackagesByRequire(const NamedPkgRel& rel, std::ostream& s) const;
 
 private:
   const ConfigCenter& m_conf;
